pilas.actores.explosion

Package pilas :: Package actores :: Module explosion |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.explosion

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  from pilas.actores import Animacion
    11
    12 -class Explosion(Animacion):
    13      """Representa una explosion para una bomba, dinamita etc...
    14
    15      El actor simplemente aparece reproduciendo un sonido y
    16      haciendo una animación:
    17
    18          >>> actor = pilas.actores.Bomba()
    19
    20      .. image:: images/actores/explosion.png
    21
    22      y una vez que termina se elimina a sí mismo.
    23
    24      Este actor también se puede anexar a cualquier
    25      otro para producir explosiones. Cuando enseñamos a un
    26      actor a explotar (por ejemplo un pingüino), el actor
    27      ``Explosion`` aparece cuando se elimina al actor::
    28
    29          >>> actor = pilas.actores.Pingu()
    30          >>> actor.aprender(pilas.habilidades.PuedeExplotar)
    31          >>> actor.eliminar()
    32      """
    33
    34
    35 -    def __init__(self, x=0, y=0):
    36          """ Constructor de la Explosion
    37
    38          :param x: Posición horizontal de la explosion.
    39          :type x: int
    40          :param y: Posición vertical de la explosion.
    41          :type y: int
    42          """
    43          grilla = pilas.imagenes.cargar_grilla("explosion.png", 7)
    44          Animacion.__init__(self, grilla, x=x, y=y)
    45          self.sonido_explosion = pilas.sonidos.cargar("explosion.wav")
    46          self.sonido_explosion.reproducir()
    47